org.openqa.selenium.server.log (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

## Package org.openqa.selenium.server.log

Class Summary
AntJettyLoggerBuildListener | Listener that can be registered to be notified when things happened during a Ant task/build.
LoggingManager | Configure logging to Selenium taste.
MaxLevelFilter | java.util.logging Filter providing finer grain control over what is logged, beyond the control provided by log levels.
ShortTermMemoryHandler | Handler who keeps in memory the last N records as is so that then can be retrieved "as is" on demand.
StdOutHandler | java.util.logging Log Handler logging everything to standard output.
TerseFormatter | Custom java.util.logging formatter providing compact output.

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV PACKAGE NEXT PACKAGE | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.